/**
 * GMyth Library
 *
 * @file gmyth/gmyth_settings.h
 * 
 * @brief <p> This component contains functions acessing and modifying 
 * user and program settings.
 * 
 * The standard settings file is created in the user home folder, in the
 * file ~/.mmyth/settings.dat.  
 *
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Alexsandro Jose Virginio dos Santos <alexsandro.santos@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GMYTH_SETTINGS_H__
#define __GMYTH_SETTINGS_H__

#include <glib-object.h>

//#include <stdio.h>
//#include <stdlib.h>
//#include <string.h>
//#include <netdb.h>
//#include <sys/socket.h>
//#include <unistd.h>

#define G_BEGIN_DECLS

#define GMYTH_SETTINGS_TYPE               (gmyth_settings_get_type ())
#define GMYTH_SETTINGS(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_SETTINGS_TYPE, GMythSettings))
#define GMYTH_SETTINGS_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_SETTINGS_TYPE, GMythSettingsClass))
#define IS_GMYTH_SETTINGS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_SETTINGS_TYPE))
#define IS_GMYTH_SETTINGS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_SETTINGS_TYPE))
#define GMYTH_SETTINGS_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GMYTH_SETTINGS_TYPE, GMythSettingsClass))


typedef struct _GMythSettings         GMythSettings;
typedef struct _GMythSettingsClass    GMythSettingsClass;

struct _GMythSettingsClass
{
  GObjectClass parent_class;

  /* callbacks */
  /* no one for now */
};

struct _GMythSettings
{
    GObject parent;

	GString *settings_file;
	
    GString *backend_hostname;
    int backend_port;

    GString *mysql_dbname;
	GString *mysql_username;
    GString *mysql_password;
    // FIXME: Why do we need database_type? Do we intend to support other dbs?
    GString *database_type;
};


GType gmyth_settings_get_type (void);

GMythSettings* gmyth_settings_new ();
gboolean gmyth_settings_load_from_file (GMythSettings *gmyth_settings, GString *filename);
gboolean gmyth_settings_load (GMythSettings *msettings);
gboolean gmyth_settings_save (GMythSettings *gmyth_settings);

GString* gmyth_settings_get_backend_hostname (GMythSettings *gmyth_settings);
void gmyth_settings_set_backend_hostname (GMythSettings *gmyth_settings, GString *new_hostname);
GString* gmyth_settings_get_username (GMythSettings *gmyth_settings);
void gmyth_settings_set_username (GMythSettings *gmyth_settings, GString *new_username);
GString* gmyth_settings_get_password (GMythSettings *gmyth_settings);
void gmyth_settings_set_password (GMythSettings *gmyth_settings, GString *new_password);
GString* gmyth_settings_get_dbname (GMythSettings *gmyth_settings);
void gmyth_settings_set_dbname (GMythSettings *gmyth_settings, GString *new_dbname);
int gmyth_settings_get_backend_port (GMythSettings *gmyth_settings);
void gmyth_settings_set_backend_port (GMythSettings *gmyth_settings, gint new_port);


#define G_END_DECLS

#endif /* __GMYTH_SETTINGS_H__ */
